@@ -1,20 +1,22 @@
 var Experiment;
 $(function () {
 
-  Experiment = function (el, name, archived_only, callback) {
+  Experiment = function (el, name, callback) {
     var that = {}, my = {};
 
     _.templateSettings.variable = 'experiment';
 
     my.el = el;
     my.name = name;
-    my.archived_only = archived_only;
     my.callback = callback;
 
     my.template = _.template($('#experiment-template').html());
 
     my.getData = function (callback) {
-      var url = '/experiment/' + my.name + '.json?period=day';
+      var url = '/experiments/' + my.name + '.json?period=day';
+      if (typeof kpi != 'undefined' && kpi !== false) {
+        url += '&kpi=' + kpi;
+      }
       $.getJSON(url, function (data) {
         callback(data);
       });
@@ -30,16 +32,6 @@ $(function () {
 
     my.getData(function (data) {
 
-      if ($('#dashboard-page').length) {
-        if (my.archived_only && !data.is_archived) {
-          my.el.remove();
-          return;
-        } else if (!my.archived_only && data.is_archived) {
-          my.el.remove();
-          return;
-        }
-      }
-
       data = my.renderBoxplots(data);
 
       // Format the rest of the data
@@ -125,8 +117,6 @@ $(function () {
       });
 
       // Normalize the boxplot data
-      max += 1;
-      min -= 1;
 
       _.each(data.alternatives, function (alt, k) {
         var start = (alt.conversion_rate - alt.confidence_interval - min) / (max - min) * 100,
@@ -148,7 +138,7 @@ $(function () {
             losing = {
               display: 'block',
               start: start,
-              end: control.start
+              end: Math.min(end, control.start)
             };
             neutral.start = control.start;
           }
@@ -157,7 +147,7 @@ $(function () {
           if (end > control.end) {
             winning = {
               display: 'block',
-              start: control.end,
+              start: Math.max(start, control.end),
               end: end
             };
             neutral.end = control.end;
